pub trait RegisterInterface<R, A>where
R: Register<Address = A>,{
type Error;
// Required methods
fn read_register(&mut self) -> Result<R, Self::Error>;
fn write_register(&mut self, register: &R) -> Result<(), Self::Error>;
}Expand description
Traits that define how to read and write the registers. Note that those functions should mostly just be implemented and not used since they are not bound by Read/Write/Edit permission.
Required Associated Types
Required Methods
Sourcefn read_register(&mut self) -> Result<R, Self::Error>
fn read_register(&mut self) -> Result<R, Self::Error>
Reads a register and returns it
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".